package App::Bin4TSV::8 ;  
our $VERSION = '0.120' ; 
our $DATE = '2021-07-04T16:27+09:00'

=encoding utf8

=head1 NAME

App::Bin4TSV::8

=head1 SYNOPSIS

This module provides a Unix-like commands of :  

  colgrep
  colsummary
  crosstable 
  csel
  csv2tsv
  digitdemog
  expandtab
  venn
 
=head1 DESCRIPTION

=head1 SEE ALSO

=cut

1 ;
